ilspycmd 9.0.0.7660-preview2

ilspycmd .NET Tool

To install:

dotnet tool install --global ilspycmd

Help output (ilspycmd --help):

ilspycmd: 8.2.0.7535
ICSharpCode.Decompiler: 8.2.0.7535

dotnet tool for decompiling .NET assemblies and generating portable PDBs

Usage: ilspycmd [options] <Assembly file name(s)>

Arguments:
  Assembly file name(s)            The list of assemblies that is being decompiled. This argument is mandatory.

Options:
  -v|--version                     Show version of ICSharpCode.Decompiler used.
  -h|--help                        Show help information.
  -o|--outputdir <directory>       The output directory, if omitted decompiler output is written to standard out.
  -p|--project                     Decompile assembly as compilable project. This requires the output directory option.
  -t|--type <type-name>            The fully qualified name of the type to decompile.
  -il|--ilcode                     Show IL code.
  --il-sequence-points             Show IL with sequence points. Implies -il.
  -genpdb|--generate-pdb           Generate PDB.
  -usepdb|--use-varnames-from-pdb  Use variable names from PDB.
  -l|--list <entity-type(s)>       Lists all entities of the specified type(s). Valid types: c(lass), i(nterface), s(truct), d(elegate), e(num)
  -lv|--languageversion <version>  C# Language version: CSharp1, CSharp2, CSharp3, CSharp4, CSharp5, CSharp6, CSharp7, CSharp7_1, CSharp7_2,
                                   CSharp7_3, CSharp8_0, CSharp9_0, CSharp10_0, Preview or Latest
                                   Allowed values are: CSharp1, CSharp2, CSharp3, CSharp4, CSharp5, CSharp6, CSharp7, CSharp7_1, CSharp7_2,
                                   CSharp7_3, CSharp8_0, CSharp9_0, CSharp10_0, CSharp11_0, Preview, Latest.
                                   Default value is: Latest.
  -r|--referencepath <path>        Path to a directory containing dependencies of the assembly that is being decompiled.
  --no-dead-code                   Remove dead code.
  --no-dead-stores                 Remove dead stores.
  -d|--dump-package                Dump package assemblies into a folder. This requires the output directory option.
  --nested-directories             Use nested directories for namespaces.
  --disable-updatecheck            If using ilspycmd in a tight loop or fully automated scenario, you might want to disable the automatic update
                                   check.

Remarks:
  -o is valid with every option and required when using -p.

Examples:
    Decompile assembly to console out.
        ilspycmd sample.dll

    Decompile assembly to destination directory (single C# file).
        ilspycmd -o c:\decompiled sample.dll

    Decompile assembly to destination directory, create a project file, one source file per type.
        ilspycmd -p -o c:\decompiled sample.dll

    Decompile assembly to destination directory, create a project file, one source file per type, 
    into nicely nested directories.
        ilspycmd --nested-directories -p -o c:\decompiled sample.dll

This package has no dependencies.

Version Downloads Last updated
11.0.0.9375 0 2026/8/12
11.0.0.9335-rc 1 2026/9/16
11.0.0.9223-preview1 2 2026/8/3
10.1.1.8388 3 2026/7/31
10.1.0.8386 2 2026/8/3
10.0.1.8346 2 2026/8/3
10.0.0.8330 2 2026/8/3
10.0.0.8323-preview3 2 2026/8/3
10.0.0.8282-preview2 2 2026/8/3
10.0.0.8079-preview1 2 2026/8/3
9.1.0.7988 2 2026/8/3
9.0.0.7889 2 2026/8/3
9.0.0.7876-RC 2 2026/8/3
9.0.0.7833-preview3 2 2026/8/3
9.0.0.7660-preview2 2 2026/8/3
9.0.0.7618-preview1 2 2026/8/3
8.2.0.7535 2 2026/8/3
8.1.1.7464 2 2026/8/3
8.1.0.7455 2 2026/8/3
8.0.0.7345 2 2026/8/3
8.0.0.7339-rc1 2 2026/8/3
8.0.0.7313-preview4 2 2026/8/3
8.0.0.7246-preview3 2 2026/8/3
8.0.0.7106-preview2 2 2026/8/3
8.0.0.7007-preview1 2 2026/8/3
7.2.1.6856 2 2026/8/3
7.2.0.6844 2 2026/8/3
7.2.0.6839-preview4 2 2026/8/3
7.2.0.6791-preview3 2 2026/8/3
7.2.0.6702-preview2 2 2026/8/3
7.1.0.6543 2 2026/8/3
7.0.0.6488 2 2026/8/3
7.0.0.6485-rc2 2 2026/8/3
7.0.0.6472-rc1 2 2026/8/3
7.0.0.6372-preview3 2 2026/8/3
7.0.0.6291-preview2 2 2026/8/3
6.2.0.6124 2 2026/8/3
6.2.0.6118-preview2 2 2026/8/3
6.2.0.6062-preview1 2 2026/8/3
6.1.0.5902 2 2026/8/3
6.0.0.5836 1 2026/8/3
6.0.0.5830-rc1 2 2026/8/3
6.0.0.5800-preview4 2 2026/8/3
6.0.0.5671-preview3 2 2026/8/3
6.0.0.5559-preview2 2 2026/8/3
6.0.0.5420-preview1 2 2026/8/3
5.0.2 2 2026/8/3
5.0.1.5145 2 2026/8/3
5.0.0.5124 2 2026/8/3
5.0.0-rc1 2 2026/8/3
5.0.0-preview4 2 2026/8/3
5.0.0-preview3 2 2026/8/3
5.0.0-preview2 2 2026/8/3
5.0.0-preview1 2 2026/8/3
4.0.0 2 2026/8/3
3.8.0 2 2026/8/3
3.5.0 2 2026/8/3
3.0.0 2 2026/8/3
2.0.0 2 2026/8/3
1.0.0 2 2026/8/3